hmda.fastcompute.globalshap: Fast Computation of Global SHAP Values

View source: R/hmda.fastcompute.globalshap.R

hmda.fastcompute.globalshapR Documentation

Fast Computation of Global SHAP Values

Description

Computes global SHAP importance from an H2O model on a new dataset

Usage

hmda.fastcompute.globalshap(model, newdata, x)

Arguments

model

An H2O model object.

newdata

An H2OFrame dataframe

x

A character vector of predictor names. Only these columns are used when computing and summarizing SHAP values.

Value

A data frame with one row per predictor and the following columns:

predictor

The predictor name.

single_shap_abs_mean

The mean absolute SHAP value of the predictor across observations in newdata.

single_shap_ratio

The normalized SHAP importance ratio. The values are scaled to sum to one across all predictors.

single_shap_rank

The rank of the predictor based on single_shap_ratio. Rank 1 indicates the largest global SHAP importance.


HMDA documentation built on Sept. 18, 2026, 5:06 p.m.