View source: R/hmda.fastcompute.globalshap.R
| hmda.fastcompute.globalshap | R Documentation |
Computes global SHAP importance from an H2O model on a new dataset
hmda.fastcompute.globalshap(model, newdata, x)
model |
An H2O model object. |
newdata |
An H2OFrame dataframe |
x |
A character vector of predictor names. Only these columns are used when computing and summarizing SHAP values. |
A data frame with one row per predictor and the following columns:
The predictor name.
The mean absolute SHAP value of the predictor
across observations in newdata.
The normalized SHAP importance ratio. The values are scaled to sum to one across all predictors.
The rank of the predictor based on
single_shap_ratio. Rank 1 indicates the largest global SHAP
importance.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.